<?php

/*
 * Discussion Board Pro Notices class
 * @since 1.3.0
 */

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

class CT_DB_Pro_Admin_Notices extends CT_DB_Pro_Admin {

	public function __construct() {
		//
	}

	/*
	 * Initialize the class and start calling our hooks and filters
	 * @since 1.0.0
	 */

	public function init() {
		add_action( 'admin_notices', array( $this, 'freshness_update' ) );
		add_action( 'admin_notices', array( $this, 'breadcrumbs_update' ) );
		add_action( 'wp_ajax_freshness_notice', array( $this, 'freshness_notice_callback' ) );
	}
	
	/**
	 * Notify freshness update required
	 * @since 1.3.0
	*/
	public function breadcrumbs_update() {
		$options = get_option( 'ctdb_boards_settings' );
		// If we've got breadcrumbs enabled from a previous version
		if( isset( $options['boards_breadcrumb'] ) ) {
			// Remove the old setting and update the new setting
			unset( $options['boards_breadcrumb'] );
			update_option( 'ctdb_boards_settings', $options );
			$general_options = get_option( 'ctdb_options_settings' );
			$general_options['enable_breadcrumbs'] = 1;
			$general_options['breadcrumbs_format'] = 'short-boards';
			update_option( 'ctdb_options_settings', $general_options );
		    ?>
   			<div class="notice notice-warning is-dismissible">
   				<p>
   					<strong><?php _e( 'Discussion Board', 'discussion-board-pro' ); ?></strong>: <?php _e( 'Just to let you know that the breadcrumbs feature has been updated. You can now set the breadcrumbs format from the General tab.', 'discussion-board-pro' ); ?>
   				</p>
   			</div>
		<?php
		}
	}
	
	/**
	 * Notify freshness update required
	 * @since 1.3.0
	*/
	public function freshness_update() {
		
		// Check if freshness has been done already
		$updated = get_option( 'ctdb_freshness_update' );

		// Check if any topics already exist. If they don't, there's no point doing this update
		$topics = new WP_Query( array('post_type'=>'discussion-topics' ) );
		
		if ( $topics->have_posts() && empty( $updated ) ) { ?>
			<div class="notice notice-info" data-notice="freshness_notice">
				<p>
					<strong><?php _e( 'Discussion Board', 'discussion-board-pro' ); ?></strong>: <?php _e( 'Discussion Board has a feature that allows you to order your topics by freshness. To allow this to work, we need to quickly update some data. Please click the button below to run the update.', 'discussion-board-pro' ); ?>
				</p>
				<p>
					<a class="button button-primary run-update" data-notice="freshness_notice" href="#"><?php _e( 'Do the update', 'discussion-board-pro' ); ?></a>
				</p>
			</div>
			<script>
				jQuery(document).ready(function($){
					$('body').on('click','.run-update',function(){
						var notice = $(this).parent().attr('data-notice');
						var data = {
							'action': 'freshness_notice',
							'notice': notice,
							'security': "<?php echo wp_create_nonce ( 'freshness_notice' ); ?>",
						}
						$.post(ajaxurl,data);
						$(this).parent().parent().fadeOut();
					});
				});
			</script>
		<?php }
		
	}
	
	/**
	 * Run update to set latest activity time on each topic
	 * @since 1.3.0
	*/
	public function freshness_notice_callback() {
		check_ajax_referer( 'freshness_notice', 'security' );
		$notice = sanitize_text_field( $_POST['notice'] );
		$option = 'ctdb_freshness_update';
		
		global $post;
		
		// Run through each topic and find the latest activity time
		// Latest activity is either time posted or time of most recent comment
		$args = array(
			'post_type'			=> 'discussion-topics',
			'posts_per_page'	=> -1
		);
		$topics = new WP_Query( $args );
		
		if( $topics->have_posts() ) {
			
			while( $topics->have_posts() ) : $topics->the_post();
				// Get most recent comment for the topic
				$comment_args = array(
					'post_id'	=> $post->ID,
					'orderby'	=> 'comment_date_gmt',
					'number'	=> 1
				);
				$latest = '';
				$comments = get_comments( $comment_args );
				if( ! empty( $comments ) ) {
					// Get time and date of most recent comment
					if( isset( $comments[0]->comment_date ) ) {
						$latest = $comments[0]->comment_date;
					}
				} else {
					// Set the time and date based on publish date
					$latest = get_the_date() . ' ' . get_the_time();
				}
			
			update_post_meta( $post->ID, 'ctdb_most_recent_activity', strtotime( $latest ) );

			endwhile;
		}
		
		// Include a check to ensure it's all done?
		update_option( $option, 1 );
	
	}

}

$CT_DB_Pro_Admin_Notices = new CT_DB_Pro_Admin_Notices();
$CT_DB_Pro_Admin_Notices->init();