<?php
/*
 * Functions for front end messages
 * Replaces original method which used text input fields in settings
 * This method is better suited for translations and multilingual sites
 * @since 1.6.2
 */

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

/**
 * Return follow_message setting
 * @since 1.6.2
 */
if( ! function_exists( 'ctdb_get_follow_message' ) ) {
	function ctdb_get_follow_message() {
		$follow_message = __( 'Follow this topic - you\'ll receive an email every time a new comment is posted', 'discussion-board-pro' );
		$options = get_option( 'ctdb_followers_settings' );
		if( isset( $options['follow_message'] ) ) {
			// If we've entered some text in the settings for Archive Title, use it
			$follow_message = $options['follow_message'];
		} else {
			// Otherwise use the filterable default value
			$follow_message = apply_filters( 'ctdb_follow_message', $follow_message );
		}
		return $follow_message;
	}
}

/**
 * Return text_after_followers setting
 * @since 1.6.2
 */
if( ! function_exists( 'ctdb_get_text_after_followers' ) ) {
	function ctdb_get_text_after_followers() {
		$text_after_followers = __( 'followers', 'discussion-board-pro' );
		$options = get_option( 'ctdb_followers_settings' );
		if( isset( $options['text_after_followers'] ) ) {
			// If we've entered some text in the settings for Archive Title, use it
			$text_after_followers = $options['text_after_followers'];
		} else {
			// Otherwise use the filterable default value
			$text_after_followers = apply_filters( 'ctdb_text_after_followers_message', $text_after_followers );
		}
		return $text_after_followers;
	}
}

/**
 * Return button_follow_text setting
 * @since 1.6.2
 */
if( ! function_exists( 'ctdb_get_button_follow_text' ) ) {
	function ctdb_get_button_follow_text() {
		$button_follow_text = __( 'Follow this topic', 'discussion-board-pro' );
		$options = get_option( 'ctdb_followers_settings' );
		if( isset( $options['button_follow_text'] ) ) {
			// If we've entered some text in the settings for Archive Title, use it
			$button_follow_text = $options['button_follow_text'];
		} else {
			// Otherwise use the filterable default value
			$button_follow_text = apply_filters( 'ctdb_button_follow_text', $button_follow_text );
		}
		return $button_follow_text;
	}
}

/**
 * Return button_unfollow_text setting
 * @since 1.6.2
 */
if( ! function_exists( 'ctdb_get_button_unfollow_text' ) ) {
	function ctdb_get_button_unfollow_text() {
		$button_unfollow_text = __( 'Unfollow this topic', 'discussion-board-pro' );
		$options = get_option( 'ctdb_followers_settings' );
		if( isset( $options['button_unfollow_text'] ) ) {
			// If we've entered some text in the settings for Archive Title, use it
			$button_unfollow_text = $options['button_unfollow_text'];
		} else {
			// Otherwise use the filterable default value
			$button_unfollow_text = apply_filters( 'ctdb_button_unfollow_text', $button_unfollow_text );
		}
		return $button_unfollow_text;
	}
}

/**
 * Return Follow this board message
 * @since 2.2.3
 */
if( ! function_exists( 'ctdb_get_follow_this_board_message' ) ) {
	function ctdb_get_follow_this_board_message() {
		$message = __( 'Follow this board', 'wp-discussion-board' );
		$message = apply_filters( 'ctdb_follow_this_board_message', $message );
		return $message;
	}
}

/**
 * Return Follow this board message
 * @since 2.2.3
 */
if( ! function_exists( 'ctdb_get_follow_this_board_message' ) ) {
	function ctdb_get_follow_this_board_message() {
		$message = __( 'Follow this board', 'wp-discussion-board' );
		$message = apply_filters( 'ctdb_follow_this_board_message', $message );
		return $message;
	}
}

/**
 * Return Unfollow this board message
 * @since 2.2.3
 */
if( ! function_exists( 'ctdb_get_unfollow_this_board_message' ) ) {
	function ctdb_get_unfollow_this_board_message() {
		$message = __( 'Unfollow this board', 'wp-discussion-board' );
		$message = apply_filters( 'ctdb_unfollow_this_board_message', $message );
		return $message;
	}
}