<?php
/**
 * Pluggable functions for profiles
 * @since 1.1.0
 */

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

/**
 * Include the sidebar if enabled
 * @since 1.1.0
 */
if( ! function_exists( 'ctdb_pro_author_sidebar' ) ) {
	function ctdb_pro_author_sidebar() {
		$options = get_option( 'ctdb_profiles_settings' );
		if( ! empty( $options['enable_author_sidebar'] ) ) {
			get_sidebar();
		}
	}
//	add_action ( 'ctdb_author_get_sidebar', 'ctdb_pro_author_sidebar' );
}

/**
 * Add the page title
 * @since 1.1.0
 */
if( ! function_exists( 'ctdb_author_template_heading' ) ) {
	function ctdb_author_template_heading() {
		$curauth = ctdb_current_author();
		if( function_exists( 'ctdb_filter_author_name' ) ) {
			$author_name = ctdb_filter_author_name( $curauth );
		} else {
			$author_name = $curauth->user_login;
		}
		?>
		<header class="entry-header ctdb-author-page-header">
			<?php printf( '<h1 class="%s">%s<h1>',
				'entry-title ctdb-page-title',
				 $author_name
			 ); ?>
		</header>
		<?php
	}
	add_action ( 'ctdb_author_header', 'ctdb_author_template_heading' );
}

/**
 * Get current author object
 * @since 1.1.0
 */
if( ! function_exists( 'ctdb_current_author' ) ) {
	function ctdb_current_author() {
		$curauth = ( get_query_var('author_name') ) ? get_user_by( 'slug', get_query_var('author_name') ) : get_userdata( get_query_var('author') );
		return $curauth;
	}
}

/**
 * List the tabs
 * @since 1.1.0
 */
if( ! function_exists( 'ctdb_profile_tabs' ) ) {
	function ctdb_profile_tabs() {
		$options = get_option( 'ctdb_profiles_settings' );
		// In case no tabs are selected
		if( ! isset( $options['profiles_tabs'] ) ) {
			return;
		}
		$tabs = $options['profiles_tabs'];
		$curauth = ctdb_current_author();
		$permalink = get_author_posts_url( $curauth->ID );

		if( ! empty( $tabs ) ) {
			// Use this array to set titles
			$tab_titles = array(
				'profile'	=> __( 'Profile', 'discussion-board-pro' ),
				'posts'		=> __( 'Topics Started', 'discussion-board-pro' ),
				'comments'	=> __( 'Replies', 'discussion-board-pro' ),
				'following'	=> __( 'Following', 'discussion-board-pro' )
			);
			// @todo set default tab to first enabled tab (profile might not be enabled)
			$current_tab = 'profile';
			if( isset( $_GET['ctdb-tab'] ) ) {
				$current_tab = $_GET['ctdb-tab'];
			}

			// Should we display the Following tab?
			// If all followed topics are public, display it
			// Otherwise, only display user's own followed topics
			if( isset( $tabs['following'] ) ) {
				$followers_options = get_option( 'ctdb_followers_settings' );
				if( ! isset( $followers_options['display_all_user_followers'] ) ) {
					// If followed topics are not public
					// Only display if current user ID matches author ID
					$userid = get_current_user_id();
					if( $userid != $curauth->ID ) {
						unset( $tabs['following'] );
					}
				}
			}

			// Wrap the list and content
			echo '<div class="ctdb-profile-wrapper">';

				echo '<div class="ctdb-profile-tabs-wrapper">';
					// Show the avatar
					echo '<div class="ctdb-profile-avatar">';
						echo get_avatar( $curauth->user_email );
					echo '</div>';
					// Create the clickable tabs
					echo '<ul class="ctdb-profile-tabs">';
					foreach( $tabs as $tab ) {
						if( isset( $tab_titles[$tab] ) ) {
							$class = '';
							if( $tab == $current_tab ) $class = 'active-tab';
							echo '<li id="profile-tab-' . $tab . '" class="' . $class . '">';
							if( $tab != $current_tab ) {
								echo '<a data-tab= "' . $tab . '" href="' . esc_url( $permalink ) . '?ctdb-tab=' . $tab . '">';
							}
							echo $tab_titles[$tab];
							if( $tab != $current_tab ) {
								echo '</a>';
							}
							echo '</li>';
						}
					}
					echo '</ul>';
				echo '</div><!-- .ctdb-profile-tabs-wrapper -->';

				// Create the content areas
				echo '<ul class="ctdb-profile-content">';
				foreach( $tabs as $tab ) {
					if( function_exists( 'ctdb_tab_' . $tab ) ) {
						$class = 'inactive-tab';
						if( $tab == $current_tab ) $class = 'active-tab';
						echo '<li id="profile-content-' . $tab . '" class="ctdb-profile-tab-content tab-' . $tab . ' ' . $class . '">';
							call_user_func( 'ctdb_tab_' . $tab );
						echo '</li><!-- .ctdb-profile-tab-content -->';
					}
				}
				echo '</ul>';

			echo '</div><!-- .ctdb-profile-wrapper -->';

		}
	}
	add_action ( 'ctdb_author_content', 'ctdb_profile_tabs' );
}

/**
 * Add the page title
 * @since 1.1.0
 */
if( ! function_exists( 'ctdb_tab_profile' ) ) {
	function ctdb_tab_profile() {
		printf( '<h2 class="%s">%s</h2>',
			'ctdb-profile-heading',
			__( 'Profile', 'discussion-board-pro' )
		);
		// Get all enabled fields
		$fields = ctdb_profile_fields();
		// Remove fields not selected
		$options = get_option( 'ctdb_profiles_settings' );
		// If no fields are selected
		if( ! isset( $options['profiles_fields'] ) ) {
			return;
		}
		$selected_profiles = $options['profiles_fields'];
		$curauth = ctdb_current_author();
		if( ! empty( $fields ) ) { ?>
		<table class="ctdb-profile-details">
			<tbody>
				<?php foreach( $fields as $field ) {
					// Check that our field is in the array of selected fields
					if( in_array( $field['id'], $selected_profiles ) ) {
						if( ! empty( $field['callback'] ) && function_exists( $field["callback"] ) ) {
							// Use callback function if it exists
							if( isset( $field['id'] ) ) {
								$value = call_user_func( $field['callback'], $curauth, $field['id'] );
							}

						} else {
							$check = $field['id'];
							$value = $curauth->$check;
						} ?>
						<tr>
							<th scope="row"><?php echo $field['label']; ?></th>
							<td><?php echo $value; ?></td>
						</tr>
					<?php }
				} ?>
			</tbody>
		</table>
		<?php }
	}
}

/**
 * Add the topics feed
 * @since 1.1.0
 */
if( ! function_exists( 'ctdb_tab_posts' ) ) {
	function ctdb_tab_posts() {
		$curauth = ctdb_current_author();
		printf( '<h2 class="%s">%s</h2>',
			'ctdb-profile-heading',
			__( 'Topics Started', 'discussion-board-pro' )
		);
		// Default WordPress loop
		// hook pre_get_posts below to specify discussion-topics post type
		// @todo allow for Recent Posts and Recent Comments (on posts) tabs as well
		if ( have_posts() ) {
			echo '<ul class="ctdb-profile-recent-entries ctdb-recent-posts">';
			while ( have_posts() ) : the_post(); ?>
				<li>
					<?php $date_format = get_option( 'date_format' );
					$date = get_the_time( $date_format, get_the_ID() ); ?>
					<?php printf( '<p class="%s"><a href="%s">%s</a><br>%s<p>',
						'ctdb-recent-entries-heading',
						esc_url( get_permalink() ),
						get_the_title(),
						$date
					 ); ?>

				</li>

			<?php endwhile;

			echo '</ul>';

			// Previous/next page navigation.
			// Pagination
			global $wp_query;
		//	$page = ( get_query_var( 'page' ) ) ? get_query_var( 'page' ) : 1;
			$big = 9999999;
			$args = array(
				'base' 		=> str_replace( $big, '%#%', esc_url( get_pagenum_link( $big ) ) ),
				'format' 	=> '?paged=%#%',
				'current' 	=> max( 1, get_query_var('paged') ),
				'total' 	=> $wp_query->max_num_pages
			);
			echo paginate_links( $args );

		} else { ?>

			<p><?php _e( 'No topics posted by this user.', 'discussion-board-pro' ); ?></p>

		<?php }
	}
}

/**
 * Modify the query on the author page
 * @since 1.1.0
 */
function ctdb_author_query( $query ) {
	$options = get_option( 'ctdb_profiles_settings' );
	if( isset( $options['enable_profiles'] ) && ! empty( $options['enable_profiles'] ) ) {
	    if ($query->is_author) {
	    	// Set post type to discussion-topics
	        $query->set( 'post_type', 'discussion-topics' );
	    }
	}
}
add_action( 'pre_get_posts', 'ctdb_author_query' );

/**
 * Add the comments feed
 * @since 1.1.0
 */
if( ! function_exists( 'ctdb_tab_comments' ) ) {
	function ctdb_tab_comments() {

		$options = get_option( 'ctdb_design_settings' );
		$comments_per_page = absint( $options['number_topics'] );

		$curauth = ctdb_current_author();
		printf( '<h2 class="%s">%s</h2>',
			'ctdb-profile-heading',
			__( 'Replies', 'discussion-board-pro' )
		);

		$total_comments = get_comments(
			array(
				'author_email'	=> $curauth->user_email,
				'count'			=> true
			)
		);

		$page = ( get_query_var( 'page' ) ) ? get_query_var( 'page' ) : 1;
		$offset = ( $page - 1 ) * $comments_per_page;

		$comments = get_comments(
			array(
				'author_email'	=> $curauth->user_email,
				'number'		=> $comments_per_page,
				'offset'		=> $offset
			)
		);

		if ( ! empty ( $comments ) ) {
			echo '<ul class="ctdb-profile-recent-entries ctdb-recent-comments">';
			foreach ( $comments as $comment ) { ?>
				<li>
					<?php $comment_date = ctdb_format_date( null, $comment->comment_date ); ?>
					<?php printf( '<p class="%s"><a href="%s">%s</a><br>%s<p>',
						'ctdb-recent-entries-heading',
						esc_url( get_permalink( $comment->comment_post_ID ) . '#comment-' . $comment->comment_ID ),
						$comment->comment_content,
						$comment_date
					 ); ?>
				</li>

			<?php }

			echo '</ul>';

			// Pagination
			$args = array(
				'base'		=> @add_query_arg( 'page', '%#%' ),
				'current' 	=> $page,
				'total'		=> ceil( $total_comments / $comments_per_page )
			);
			echo paginate_links( $args );

		} else { ?>

			<p><?php _e( 'No replies posted by this user.', 'discussion-board-pro' ); ?></p>

		<?php }

	}
}

/**
 * Return the available profile fields to display on the Profile tab
 * Also used by CT_DB_Pro_Admin to populate Profile fields setting
 * @since 1.1.1
 */
if( ! function_exists( 'ctdb_profile_fields' ) ) {
	function ctdb_profile_fields() {
		$fields = array(
			'display_name'		=> array(
				'id'		=> 'display_name',
				'label'		=> __( 'Display name', 'discussion-board-pro' ),
				'callback'	=> ''
			),
			'first_name'		=> array(
				'id'		=> 'first_name',
				'label'		=> __( 'First name', 'discussion-board-pro' ),
				'callback'	=> ''
			),
			'last_name'			=> array(
				'id'		=> 'last_name',
				'label'		=> __( 'Last name', 'discussion-board-pro' ),
				'callback'	=> ''
			),
			'user_url'			=> array(
				'id'		=> 'user_url',
				'label'		=> __( 'Website', 'discussion-board-pro' ),
				'callback'	=> 'ctdb_profile_user_url_callback'
			),
			'description'		=> array(
				'id'		=> 'description',
				'label'		=> __( 'Bio', 'discussion-board-pro' ),
				'callback'	=> ''
			),
			'user_registered'	=> array(
				'id'		=> 'user_registered',
				'label'		=> __( 'Member since', 'discussion-board-pro' ),
				'callback'	=> 'ctdb_profile_user_registered_callback'
			),
			'topics_posted'		=> array(
				'id'		=> 'topics_posted',
				'label'		=> __( 'Topics posted', 'discussion-board-pro' ),
				'callback'	=> 'ctdb_profile_topics_posted_callback'
			),
			'replies'			=> array(
				'id'		=> 'replies',
				'label'		=> __( 'Replies', 'discussion-board-pro' ),
				'callback'	=> 'ctdb_profile_replies_callback'
			),
		);
		$fields = apply_filters( 'ctdb_profile_fields', $fields );
		return $fields;
	}
}

/**
 * Return the user's website url as a link
 * @since 1.1.1
 */
if( ! function_exists( 'ctdb_profile_user_url_callback' ) ) {
	function ctdb_profile_user_url_callback( $author, $field ) {
		$url = $author->user_url;
		$return = '<a href="' . esc_url ( $url ) . '">' . esc_url( $url ) . '</a>';
		return $return;
	}
}

/**
 * Return the user's website url as a link
 * @since 1.1.1
 */
if( ! function_exists( 'ctdb_profile_user_registered_callback' ) ) {
	function ctdb_profile_user_registered_callback( $author, $field ) {
		$registered = $author->user_registered;
		$return = ctdb_format_date( $author, $registered );
		return $return;
	}
}

/**
 * Return date formatted as specified in Settings
 * @since 1.1.1
 */
if( ! function_exists( 'ctdb_format_date' ) ) {
	function ctdb_format_date( $author=null, $date ) {
		$date_format = get_option( 'date_format' );
		$return = new DateTime( $date );
		$return = $return->format( $date_format );
		return $return;
	}
}

/**
 * Return the number of topics posted by a user
 * @since 1.1.1
 */
if( ! function_exists( 'ctdb_profile_topics_posted_callback' ) ) {
	function ctdb_profile_topics_posted_callback( $author, $id ) {
		$return = count_user_posts( $author->ID, 'discussion-topics' );
		return $return;
	}
}

/**
 * Return the number of topic replies posted by a user
 * @since 1.1.1
 */
if( ! function_exists( 'ctdb_profile_replies_callback' ) ) {
	function ctdb_profile_replies_callback( $author, $id ) {
		$total_comments = get_comments(
			array(
				'author_email'	=> $author->user_email,
				'count'			=> true,
				'post_type'		=> 'discussion-topics'
			)
		);
		return $total_comments;
	}
}

/**
 * Add the topics feed
 * @since 1.1.0
 */
if( ! function_exists( 'ctdb_tab_following' ) ) {
	function ctdb_tab_following() {
		global $post;
		$curauth = ctdb_current_author();
		printf( '<h2 class="%s">%s</h2>',
			'ctdb-profile-heading',
			__( 'Topics Following', 'discussion-board-pro' )
		);

		$options = get_option( 'ctdb_design_settings' );
		$topics_per_page = absint( $options['number_topics'] );

		$page = ( get_query_var( 'page' ) ) ? get_query_var( 'page' ) : 1;
		$offset = ( $page - 1 ) * $topics_per_page;
		$args = array(
			'post_type'			=> 'discussion-topics',
			'posts_per_page'	=> $topics_per_page,
			'offset'			=> $offset
		);
		$following = new WP_Query($args);

		if ( $following->have_posts() ) {
			$count = 0;
			echo '<ul class="ctdb-profile-recent-entries ctdb-recent-posts">';
			while ( $following->have_posts() ) : $following->the_post();

			$followers = get_post_meta( $post->ID, 'ctdb_follow_this_topic', true );
				if( ! empty( $followers ) && in_array( $curauth->ID, $followers ) ) { ?>
					<li>
						<?php
							printf( '<p class="%s"><a href="%s">%s</a><br>%s<p>',
							'ctdb-recent-entries-heading',
							esc_url( get_permalink() ),
							get_the_title(),
							get_the_time( 'd M Y' )
						 );
						 $count++; ?>
					</li>
				<?php }
			endwhile;

			echo '</ul>';

			// Previous/next page navigation.
			$args = array(
				'base'		=> @add_query_arg( 'page', '%#%' ),
				'current' 	=> $page,
				'total'		=> ceil( $count / $topics_per_page )
			);
			echo paginate_links( $args );

		}
		if( $count == 0 ) { ?>
			<p><?php _e( 'No topics followed by this user.', 'discussion-board-pro' ); ?></p>
		<?php }
	}
}
