<?php
/*
 * Discussion Board public class
*/
// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}
/**
 * Plugin public class
 **/
class CT_DB_Pro_Public extends CT_DB_Public {
	
	public function __construct() {
		
		$CT_DB_Pro_Categories = new CT_DB_Pro_Categories();
		$CT_DB_Pro_Categories -> init();
		$CT_DB_Pro_New_Topic = new CT_DB_Pro_New_Topic();
		$CT_DB_Pro_New_Topic -> init();
		$CT_DB_Pro_Registration = new CT_DB_Pro_Registration();
		$CT_DB_Pro_Registration -> init();
		
	}
	
	/*
	 * Initialize the class and start calling our hooks and filters
	 * @since 1.0.0
	 */
	public function init() {
		
		add_filter( 'body_class', array( $this, 'filter_body_classes' ) );
		add_action( 'wp_enqueue_scripts', array( $this, 'enqueue_scripts' ) );
		add_filter( 'ctdb_post_args', array( $this, 'filter_post_args' ) );
		add_filter( 'wp_insert_comment', array( $this, 'approve_comment' ), 99, 2 );
		add_filter( 'post_thumbnail_html', array( $this, 'filter_featured_image' ), 10, 5 );
		
		// Add editor to comment form
		add_filter( 'comment_form_fields', array( $this, 'comment_form' ) );

		// Comment media reply fix.
		add_action( 'wp_footer', array( $this, 'comments_reply_wysiwyg_fix_js' ), 9999 );
		
		// Freshness args for shortcode
		add_action( 'publish_discussion-topics', array( $this, 'set_publish_date' ), 10, 2 );
		add_action( 'comment_post', array( $this, 'set_comment_date' ), 10, 3 );
		add_filter( 'ctdb_discussion_topics_shortcode_orderby', array( $this, 'orderby_params' ) );
		
		/* Filter the shortcode args
		 * Params $args $atts
		 * Passing in $atts allows us to add additional parameters to the query
		 */
		add_filter( 'ctdb_discussion_topics_shortcode_args', array( $this, 'shortcode_args' ), 10, 2 );
		
		add_filter( 'ctdb_topic_titles', array( $this, 'topic_titles' ) );
		add_filter( 'ctdb_topic_column', array( $this, 'extra_columns' ), 10, 3 );
		add_filter( 'ctdb_mobile_body_fields', array( $this, 'extra_mobile_metafields' ), 10, 3 );
		
		add_action( 'widgets_init', array( $this, 'widgets_init' ) );
		
	}
	
	public function filter_body_classes( $classes ) {
		// Do we need to add Timeago script?
		$options = get_option( 'ctdb_pro_settings' );
		if( isset( $options['freshness_time_format'] ) && $options['freshness_time_format'] == 'freshness' ) {
			$classes[] = 'ctdb-freshness-timeago';
		}
		if( isset( $options['time_format'] ) && $options['time_format'] == 'freshness' ) {
			$classes[] = 'ctdb-standard-timeago';
		}
		$options = get_option( 'ctdb_pro_settings' );
		if( isset( $options['enable_comments_tinymce'] ) ) {
			$classes[] = 'ctdb-comments-tinymce';
		}
	
		return $classes;
	}
	
	
	/*
	 * Enqueue our scripts
	 * @since 1.1.0
	 */
	public function enqueue_scripts() {
		wp_enqueue_script( 'ctdb-script', DB_PRO_PLUGIN_URL . 'assets/js/ctdb.js', array( 'jquery' ), DB_PRO_VERSION, true );
		wp_localize_script( 'ctdb-script', 'ajax_object', array( 
			'ajaxurl'			=> admin_url( 'admin-ajax.php' ),
			'postid' 			=> get_the_id(),
			'userid'			=> get_current_user_id(),
			'follow_board'		=> ctdb_get_follow_this_board_message(),
			'unfollow_board'	=> ctdb_get_unfollow_this_board_message()
		) );
		wp_enqueue_style( 'ctdb-pro-style', DB_PRO_PLUGIN_URL . 'assets/css/style.css', array(), DB_PRO_VERSION );
			
		// Do we need to enqueue Timeago?
		$options = get_option( 'ctdb_design_settings' );
		
		// How to display the freshness value
		if( ! isset( $options['time_format'] ) || $options['time_format'] == 'time_since' ) {
			wp_enqueue_script( 'timeago', DB_PRO_PLUGIN_URL . 'assets/js/jquery.timeago.js', array( 'jquery' ), '1.5.3', true );
		}

	}
	
	// Filter fields saved when creating new topic to wp_insert_post
	public function filter_post_args( $post_args ) {
		return $post_args;	
	}
	
	/**
	 * Automatically approve comments if selected	 
	 * @since 1.0.0	 
	*/
	public function approve_comment ( $comment_id, $comment_object ) {
		$options = get_option( 'ctdb_pro_settings' );
		// Only auto allow comments if option enabled and correct post type
		$post_id = $comment_object -> comment_post_ID;
		if ( ! empty( $options['always_allow_comments'] ) && 'discussion-topics' == get_post_type ( $post_id ) ) {
			$ret_comment = get_comment ( $comment_id, ARRAY_A );
			$comment_arr = $ret_comment;
			$comment_arr['comment_ID'] = $comment_id;
			$comment_arr['comment_approved'] = 1;
			wp_update_comment( $comment_arr );
			// Update the most recent activity metafield
			$time = time();
			update_post_meta( $post_id, 'ctdb_most_recent_activity', $time );
		}
	}
	
	/**
	 * Filter the featured image if there is one
	 * @since 1.0.0
	*/
	public function filter_featured_image ( $html, $post_id, $post_thumbnail_id, $size, $attr ) {		
		// If we're on a single page for the discussion-topic post type and we don't have access	
		if ( ( is_single() || is_archive() ) && 'discussion-topics' == get_post_type() ) {		
			if ( ! ctdb_is_user_permitted() ) {				
				// Remove the featured image				
				$html = '';
			}		
		}		
		return $html;			
	}
	
	/**
	 * When a post is published, add the publish date in the ctdb_most_recent_activity meta field
	 * @since 1.3.0
	*/
	public function set_publish_date( $ID, $post ) {
		global $post;
		// We want to make sure this doesn't update the meta every time the topic is edited
		// Ensure that freshness doesn't update incorrectly when editing back end for boards
		$recent = get_post_meta( $ID, 'ctdb_most_recent_activity' );
		if( empty( $recent ) ) {
			$time = time();
			update_post_meta( $ID, 'ctdb_most_recent_activity', $time );
		}
	}
	
	/**
	 * When a comment is published, add the publish date to its post parent
	 * @since 1.3.0
	*/
	public function set_comment_date( $comment_ID, $comment_approved, $commentdata ) {
		if( $comment_approved == 1 ) {
			// Get the post ID and update the meta
			$post_id = $commentdata['comment_post_ID'];
			$time = time();
			update_post_meta( $post_id, 'ctdb_most_recent_activity', $time );
		}
		
	}
	
	/**
	 * Filter the permitted orderby params list
	 * @since 1.3.0
	*/
	public function orderby_params( $permitted_params ) {		
		// Add freshness parameter
		$permitted_params[] = 'freshness';
		$permitted_params[] = 'status';
		return $permitted_params;
	}
	
	/**
	 * Filter the shortcode args
	 * If orderby param is set to freshness, find most recently commented / posted
	 * @since 1.3.0
	*/
	public function shortcode_args( $args, $atts ) {
		
		if( isset( $args['orderby'] ) && $args['orderby'] == 'freshness' ) {
			// Only run this if freshness is actually specified, obvs
			// Add metafield to each discussion topic with last comment timestamp
			$args['orderby'] = 'meta_value_num';
			$args['meta_key'] = 'ctdb_most_recent_activity';
		}
		// Look for additional attributes not handled by the free version
		if( isset( $atts['categories'] ) ) {
			// Add tax_query for Categories
			$args['tax_query'] = array(
				array(
					'taxonomy'	=> 'topic-category',
					'field'		=> 'term_id',
					'terms'		=> explode( ',', $atts['categories'] ),
					'operator'	=> 'IN'
				)
			);
		}
		// Look for additional attributes not handled by the free version
		if( isset( $atts['board'] ) ) {
			// Add tax_query for Categories
			$args['tax_query'] = array(
				array(
					'taxonomy'	=> 'board',
					'field'		=> 'term_id',
					'terms'		=> array( intval( $atts['board'] ) ),
					'operator'	=> 'IN'
				)
			);
		}
		// Filter status
		if( isset( $atts['status'] ) ) {
			// Add tax_query for Categories
			$args['meta_query'] = array(
				array(
					'key'		=> 'ctdb_topic_status',
					'value'		=> $atts['status']
				)
			);
		}

		return $args;
		
	}
	
	/**	 
	 * Filter comment form
	 * @since 1.5.3
	*/
	public function comment_form( $fields ) {
		global $allowedtags;

		$options = get_option( 'ctdb_pro_settings' );

		if ( ! isset( $options['enable_comments_tinymce'] ) ) {
			return $fields;
		}

		$media = false;

		if ( isset( $options['enable_media_button'] ) ) {
			$media = true;

			$allowedtags['img'] = array( // phpcs:ignore
				'class'  => array(),
				'src'    => array(),
				'alt'    => array(),
				'width'  => array(),
				'height' => array(),
			);
		}

		ob_start();
		wp_editor(
			'',
			'comment',
			array(
				'teeny'         => true,
				'textarea_rows' => 5,
				'media_buttons' => $media,
				'quicktags'     => false,
			)
		);
		$fields['comment'] = ob_get_clean();

		return $fields;
	}

	/**
	 * Fix to get TinyMCE to work with comment form replies.
	 *
	 * @since 1.8.10
	 */
	public function comments_reply_wysiwyg_fix_js() {
		if ( ! is_singular( 'discussion-topics' ) ) {
			return;
		}
		?>
		<script type="text/javascript">
			jQuery( document ).ready( function() {
				if ( typeof addComment === 'undefined' ) {
					return;
				}

				var extendAddComment = addComment;
				addComment = {
					moveForm: function ( commId, parentId, respondId, postId ) {
						var returnValue = extendAddComment.moveForm(commId, parentId, respondId, postId);
						tinymce.EditorManager.execCommand( 'mceRemoveEditor', true, 'comment' );
						tinymce.EditorManager.execCommand( 'mceAddEditor', true, 'comment' );
						tinymce.activeEditor.setContent( "" );
						return returnValue;
					}
				};

				jQuery( 'body' ).on( 'click', '#cancel-comment-reply-link', function () {
					tinymce.EditorManager.execCommand( 'mceRemoveEditor', true, 'comment' );
					tinymce.EditorManager.execCommand( 'mceAddEditor', true, 'comment' );
					tinymce.activeEditor.setContent( "" );
				} );
			});
		</script>
		<?php
	}

	/**
	 * Additional table column titles
	 * @since 1.3.0
	*/
	public function topic_titles( $titles ) {		
		$titles['freshness'] = __( 'Freshness', 'discussion-board-pro' );
		$titles['status'] = __( 'Status', 'discussion-board-pro' );
		return $titles;
	}
	
	/**
	 * Filter the shortcode column
	 * Add extra column data if required
	 * @since 1.3.0
	*/
	public function extra_columns( $body_fields, $post_id, $col ) {

		if( $col == 'freshness' ) {
			$options = get_option( 'ctdb_design_settings' );
			
			$date = get_post_meta( $post_id, 'ctdb_most_recent_activity', true );
			if( ! empty( $date ) ) {
				$format = get_option( 'date_format' );
				$body_fields[$post_id] .= '<time class="timeago" datetime="' . date( 'c', $date ) . '">' . date( $format, $date ) . '</time>';
			}
			
		} else if( $col == 'status' ) {
			
			$status = ctdb_status( $post_id );
			$body_fields[$post_id] .= $status;
			
		}

		return $body_fields;
		
	}
	
	/**
	 * Add extra metafields for mobile
	 * @since 1.6.2
	*/
	public function extra_mobile_metafields( $mobile_body_fields, $post_id, $cols ) {
		if( in_array( 'freshness', $cols ) ) {
			$options = get_option( 'ctdb_design_settings' );
			$date = get_post_meta( $post_id, 'ctdb_most_recent_activity', true );
			if( ! empty( $date ) ) {
				$format = get_option( 'date_format' );
				$mobile_body_fields .= '<div>';
				$mobile_body_fields .= __( 'Freshness', 'wp-discussion-board' );
				$mobile_body_fields .= ': ';
				$mobile_body_fields .= '<time class="timeago" datetime="' . date( 'c', $date ) . '">' . date( $format, $date ) . '</time>';
				$mobile_body_fields .= '</div>';
			}
			
		}
		if( in_array( 'status', $cols ) ) {
			
			$status = ctdb_status( $post_id );
			$mobile_body_fields .= '<div>';
			$mobile_body_fields .= __( 'Status', 'wp-discussion-board' );
			$mobile_body_fields .= ': ';
			$mobile_body_fields .= $status;
			$mobile_body_fields .= '</div>';
			
		}

		return $mobile_body_fields;
		
	}
	
	
	/**
	 * Add some script to the shortcode
	 * @since 1.3.0
	 */
	public function add_shortcode_script( $output ) {
			
		// Do we need to add Timeago script?
		$options = get_option( 'ctdb_design_settings' );
		
		// How to display the freshness value
		if( ! isset( $options['time_format'] ) || $options['time_format'] == 'time_since' ) {
			$output .= '<script>
					jQuery(document).ready(function($){
						$("time.timeago").timeago();
					});
				</script>';
		}
		
		return $output;

	}

	/**
	 * Register our widgets
	 * @since 1.1.1.
	*/
	public function widgets_init() {
		register_widget ( 'WP_Widget_DB_Login' );
		register_widget ( 'WP_Widget_Recent_Topics' );
		register_widget ( 'WP_Widget_Recent_Replies' );
		register_widget ( 'WP_Widget_Top_Posters' );
		register_widget ( 'WP_Widget_Top_Commenters' );
	}
	
}