<?php
/*
 * Template Loader class
*/

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

/**
 * Plugin public class
 **/
if ( class_exists( 'CT_DB_Template_Loader' ) ) {

	class CT_DB_Pro_Template_Loader extends CT_DB_Template_Loader {

		public function __construct() {
			//
		}
		
		/*
		 * Initialize the class and start calling our hooks and filters
		 * @since 1.0.0
		 */
		public function init() {
			add_filter ( 'author_template', array ( $this, 'filter_author_template' ), 9999 );
			add_filter ( 'taxonomy_template', array ( $this, 'filter_board_tax_template' ) );
		}
		
		
		/*
		 * Filters the author template
		 * @since 1.0.0
		 * @reference https://codex.wordpress.org/Plugin_API/Filter_Reference/archive_template
		 */
		public function filter_author_template ( $author_template ) {

			$options = get_option( 'ctdb_profiles_settings' );
			
			if ( is_author() ) {

				// The hierarchy of where to find the template
				// Check child theme first
				if ( file_exists ( trailingslashit ( get_stylesheet_directory() ) . 'author.php' ) && ! isset( $options['enable_profiles'] ) ) {
					$author_template = trailingslashit ( get_stylesheet_directory() ) . 'author.php';

				// Check parent theme next
				} elseif ( file_exists( trailingslashit( get_template_directory() ) . 'author.php' ) && ! isset( $options['enable_profiles'] ) ) {
					$author_template = trailingslashit( get_template_directory() ) . 'author.php';

				// Check plugin file last
				// Profiles must be enabled to load the author.php template
				// Otherwise we'll load whatever comes next in the hierarchy, e.g archive.php
				} elseif ( file_exists ( DB_PRO_PLUGIN_DIR . '/templates/author.php' ) && ! empty( $options['enable_profiles'] ) ) {
					$author_template = DB_PRO_PLUGIN_DIR . '/templates/author.php';
				}
				
			}

			return $author_template;
			
		}
		
		/*
		 * Filters the board taxonomy template
		 * @since 1.5.0
		 * @reference https://codex.wordpress.org/Plugin_API/Filter_Reference/archive_template
		 */
		public function filter_board_tax_template ( $template ) {
			
			if( 'discussion-topics' != get_post_type() ) {
				return $template;
			}
			
			$options = get_option( 'ctdb_boards_settings' );
			
			// The hierarchy of where to find the template
			// Check child theme first
			if ( file_exists ( trailingslashit ( get_stylesheet_directory() ) . 'taxonomy-board.php' ) ) {
				$template = trailingslashit ( get_stylesheet_directory() ) . 'taxonomy-board.php';

			// Check parent theme next
			} elseif ( file_exists( trailingslashit( get_template_directory() ) . 'taxonomy-board.php' ) ) {
				$template = trailingslashit( get_template_directory() ) . 'taxonomy-board.php';

			// Check plugin file last
			// Profiles must be enabled to load the author.php template
			// Otherwise we'll load whatever comes next in the hierarchy, e.g archive.php
			} elseif ( file_exists ( DB_PRO_PLUGIN_DIR . '/templates/taxonomy-board.php' ) && ! empty( $options['boards_override_template'] ) ) {
				$template = DB_PRO_PLUGIN_DIR . '/templates/taxonomy-board.php';
			}

			return $template;
			
		}
		
	}
	
}